package com.jiuqi.dna.ide.designer;

import com.jiuqi.dna.ide.designer.elements.CompositeElement;
import com.jiuqi.dna.ide.designer.elements.FigureElement;
import com.jiuqi.dna.ide.designer.elements.ICompositeElement;
import com.jiuqi.dna.ide.designer.elements.IDesignerElement;
import com.jiuqi.dna.ide.designer.elements.IFigureElement;
import com.jiuqi.dna.ide.designer.elements.ILayoutDataElement;
import com.jiuqi.dna.ide.designer.elements.ILayoutElement;
import com.jiuqi.dna.ide.designer.elements.IRootElement;
import com.jiuqi.dna.ide.designer.elements.LayoutDataElement;
import com.jiuqi.dna.ide.designer.elements.LayoutElement;
import com.jiuqi.dna.ide.designer.elements.RootElement;
import com.jiuqi.dna.ide.designer.events.CompositeEvent;
import com.jiuqi.dna.ide.designer.events.DesignerElementEvent;
import com.jiuqi.dna.ide.designer.events.FigureEvent;
import com.jiuqi.dna.ide.designer.events.ICompositeListener;
import com.jiuqi.dna.ide.designer.events.IDesignerElementListener;
import com.jiuqi.dna.ide.designer.events.IFigureListener;
import com.jiuqi.dna.ide.designer.events.ISelectionListener;
import com.jiuqi.dna.ide.designer.events.SelectionEvent;
import com.jiuqi.dna.ide.designer.toolkit.ToolkitElement;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Comparator;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Set;
import org.eclipse.jface.action.IAction;

/* loaded from: com_jiuqi_dna_ide_designer.jar:com/jiuqi/dna/ide/designer/DesignerBase.class */
public abstract class DesignerBase {
    private IRootElement rootElement;
    private ArrayList<IDesignerElementListener> designerElementListeners = new ArrayList<>();
    private ArrayList<IFigureListener> figureListeners = new ArrayList<>();
    private ArrayList<ICompositeListener> compositeListeners = new ArrayList<>();
    private ArrayList<ISelectionListener> selectionListeners = new ArrayList<>();
    protected ArrayList<IDesignerElement> selectedElements = new ArrayList<>();
    private HashMap<String, ArrayList<IAction>> contextMenus = new HashMap<>();
    private boolean eventEnabled = true;

    public void addDesignerElementListener(IDesignerElementListener listener) {
        this.designerElementListeners.add(listener);
    }

    public void removeDesignerElementListener(IDesignerElementListener listener) {
        this.designerElementListeners.remove(listener);
    }

    public IDesignerElementListener[] getDesignerElementListeners() {
        IDesignerElementListener[] listeners = new IDesignerElementListener[this.designerElementListeners.size()];
        return (IDesignerElementListener[]) this.designerElementListeners.toArray(listeners);
    }

    public void addFigureListener(IFigureListener listener) {
        this.figureListeners.add(listener);
    }

    public void removeFigureListener(IFigureListener listener) {
        this.figureListeners.remove(listener);
    }

    public IFigureListener[] getFigureListeners() {
        IFigureListener[] listeners = new IFigureListener[this.figureListeners.size()];
        return (IFigureListener[]) this.figureListeners.toArray(listeners);
    }

    public void addCompositeListener(ICompositeListener listener) {
        this.compositeListeners.add(listener);
    }

    public void removeCompositeListener(ICompositeListener listener) {
        this.compositeListeners.remove(listener);
    }

    public ICompositeListener[] getCompositeListeners() {
        ICompositeListener[] listeners = new ICompositeListener[this.compositeListeners.size()];
        return (ICompositeListener[]) this.compositeListeners.toArray(listeners);
    }

    public void addSelectionListener(ISelectionListener listener) {
        this.selectionListeners.add(listener);
    }

    public void removeSelectionListener(ISelectionListener listener) {
        this.selectionListeners.remove(listener);
    }

    public ISelectionListener[] getSelectionListeners() {
        ISelectionListener[] listeners = new ISelectionListener[this.selectionListeners.size()];
        return (ISelectionListener[]) this.selectionListeners.toArray(listeners);
    }

    public IRootElement getRootElement() {
        if (this.rootElement == null) {
            RootElement root = new RootElement();
            root.setDesigner(this);
            root.setToolkitElement(new ToolkitElement());
            root.init();
            this.rootElement = root;
        }
        return this.rootElement;
    }

    public void setRootElement(IRootElement rootElement) {
        disableEvent();
        initRootElement();
        enableEvent();
        this.rootElement = rootElement;
    }

    private void initRootElement() {
        if (this.rootElement == null) {
            return;
        }
        if (!this.rootElement.isInitialized() && this.rootElement.isInitializable()) {
            this.rootElement.init();
        }
        if (!this.rootElement.isInitialized()) {
            return;
        }
        Iterator it = this.rootElement.getFigureChildren().iterator();
        while (it.hasNext()) {
            IFigureElement figure = (IFigureElement) it.next();
            if (figure instanceof ICompositeElement) {
                initFigureElements((ICompositeElement) figure);
            } else if (!figure.isInitialized() && figure.isInitializable()) {
                figure.init();
            }
        }
        Iterator it2 = this.rootElement.getNonFigureChildren().iterator();
        while (it2.hasNext()) {
            IDesignerElement element = (IDesignerElement) it2.next();
            if (!element.isInitialized() && element.isInitializable()) {
                element.init();
            }
        }
        Iterator it3 = this.rootElement.getFigureChildren().iterator();
        while (it3.hasNext()) {
            IFigureElement figure2 = (IFigureElement) it3.next();
            if (figure2 instanceof ICompositeElement) {
                initNonFigureElements((ICompositeElement) figure2);
            }
        }
    }

    private void initFigureElements(ICompositeElement composite) {
        if (composite == null) {
            return;
        }
        if (!composite.isInitialized() && composite.isInitializable()) {
            composite.init();
        }
        if (!composite.isInitialized()) {
            return;
        }
        Iterator it = composite.getFigureChildren().iterator();
        while (it.hasNext()) {
            IFigureElement figure = (IFigureElement) it.next();
            if (figure instanceof ICompositeElement) {
                initFigureElements((ICompositeElement) figure);
            } else if (!figure.isInitialized() && figure.isInitializable()) {
                figure.init();
            }
        }
    }

    private void initNonFigureElements(ICompositeElement composite) {
        if (composite == null) {
            return;
        }
        Iterator it = composite.getNonFigureChildren().iterator();
        while (it.hasNext()) {
            IDesignerElement element = (IDesignerElement) it.next();
            if (!element.isInitialized() && element.isInitializable()) {
                element.init();
            }
        }
        Iterator it2 = composite.getFigureChildren().iterator();
        while (it2.hasNext()) {
            IFigureElement figure = (IFigureElement) it2.next();
            if (figure instanceof ICompositeElement) {
                initNonFigureElements((ICompositeElement) figure);
            }
        }
    }

    public <T extends IDesignerElement> T createElement(Class<T> clazz) {
        if (clazz == IRootElement.class || clazz == RootElement.class) {
            RootElement element = new RootElement();
            element.setDesigner(this);
            return element;
        }
        if (clazz == ICompositeElement.class || clazz == CompositeElement.class) {
            CompositeElement element2 = new CompositeElement();
            element2.setDesigner(this);
            return element2;
        }
        if (clazz == IFigureElement.class || clazz == FigureElement.class) {
            FigureElement element3 = new FigureElement();
            element3.setDesigner(this);
            return element3;
        }
        if (clazz == ILayoutElement.class || clazz == LayoutElement.class) {
            LayoutElement element4 = new LayoutElement();
            element4.setDesigner(this);
            return element4;
        }
        if (clazz == ILayoutDataElement.class || clazz == LayoutDataElement.class) {
            T element5 = new LayoutDataElement();
            element5.setDesigner(this);
            return element5;
        }
        return null;
    }

    public void updateElement(IDesignerElement element) {
    }

    public void updateRootElement() {
    }

    public void addSelectedElement(IDesignerElement element) {
        if (element == null) {
            throw new NullPointerException("参数element不能为NULL！");
        }
        this.selectedElements.add(element);
        fireElementSelected(new IDesignerElement[]{element});
    }

    public void addSelectedElements(IDesignerElement[] elements) {
        if (elements == null) {
            throw new NullPointerException("参数elements不能为NULL！");
        }
        for (IDesignerElement element : elements) {
            this.selectedElements.add(element);
        }
        fireElementSelected(elements);
    }

    public void setSelectedElement(IDesignerElement element) {
        if (element == null) {
            throw new NullPointerException("参数element不能为NULL！");
        }
        this.selectedElements.clear();
        addSelectedElement(element);
    }

    public void setSelectedElements(IDesignerElement[] elements) {
        if (elements == null) {
            throw new NullPointerException("参数elements不能为NULL！");
        }
        this.selectedElements.clear();
        addSelectedElements(elements);
    }

    public IDesignerElement[] getSelectedElements() {
        IDesignerElement[] elements = new IDesignerElement[this.selectedElements.size()];
        return (IDesignerElement[]) this.selectedElements.toArray(elements);
    }

    public void removeSelectedElement(IDesignerElement element) {
        this.selectedElements.remove(element);
    }

    public void addContextMenuAction(String groupName, IAction action) {
        ArrayList<IAction> actionList = this.contextMenus.get(groupName);
        if (actionList == null) {
            actionList = new ArrayList<>();
        }
        actionList.add(action);
        this.contextMenus.put(groupName, actionList);
    }

    public IAction getContextMenuAction(String groupName, String actionId) {
        ArrayList<IAction> actionList = this.contextMenus.get(groupName);
        if (actionList == null) {
            return null;
        }
        Iterator<IAction> it = actionList.iterator();
        while (it.hasNext()) {
            IAction action = it.next();
            if (action.getId().equals(actionId)) {
                return action;
            }
        }
        return null;
    }

    public IAction removeContextMenuAction(String groupName, String actionId) {
        ArrayList<IAction> actionList = this.contextMenus.get(groupName);
        if (actionList == null) {
            return null;
        }
        Iterator<IAction> it = actionList.iterator();
        while (it.hasNext()) {
            IAction action = it.next();
            if (action.getId().equals(actionId)) {
                actionList.remove(action);
                return action;
            }
        }
        return null;
    }

    public IAction[] removeContextMenuGroup(String groupName) {
        ArrayList<IAction> actionList = this.contextMenus.remove(groupName);
        if (actionList == null) {
            return null;
        }
        IAction[] actions = new IAction[actionList.size()];
        return (IAction[]) actionList.toArray(actions);
    }

    public String[] getMenuGroupNames() {
        Set<String> groups = this.contextMenus.keySet();
        String[] groupNames = (String[]) groups.toArray(new String[groups.size()]);
        Arrays.sort(groupNames, new Comparator<String>() { // from class: com.jiuqi.dna.ide.designer.DesignerBase.1
            @Override // java.util.Comparator
            public int compare(String str1, String str2) {
                return str1.compareTo(str2);
            }
        });
        return groupNames;
    }

    public IAction[] getMenuGroup(String groupName) {
        ArrayList<IAction> actionList = this.contextMenus.get(groupName);
        if (actionList == null) {
            return null;
        }
        IAction[] actions = new IAction[actionList.size()];
        return (IAction[]) actionList.toArray(actions);
    }

    protected boolean isEventEnabled() {
        return this.eventEnabled;
    }

    protected void enableEvent() {
        this.eventEnabled = true;
    }

    protected void disableEvent() {
        this.eventEnabled = false;
    }

    public void fireElementCreate(IDesignerElement element) {
        if (!isEventEnabled()) {
            return;
        }
        DesignerElementEvent event = new DesignerElementEvent(this);
        event.element = element;
        Iterator<IDesignerElementListener> it = this.designerElementListeners.iterator();
        while (it.hasNext()) {
            IDesignerElementListener listener = it.next();
            listener.elementCreate(event);
        }
    }

    public void fireElementDelete(IDesignerElement element) {
        if (!isEventEnabled()) {
            return;
        }
        DesignerElementEvent event = new DesignerElementEvent(this);
        event.element = element;
        Iterator<IDesignerElementListener> it = this.designerElementListeners.iterator();
        while (it.hasNext()) {
            IDesignerElementListener listener = it.next();
            listener.elementDelete(event);
        }
    }

    public void firePropertyChange(IDesignerElement element, String propertyName) {
        if (!isEventEnabled()) {
            return;
        }
        DesignerElementEvent event = new DesignerElementEvent(this);
        event.element = element;
        event.propertyName = propertyName;
        Iterator<IDesignerElementListener> it = this.designerElementListeners.iterator();
        while (it.hasNext()) {
            IDesignerElementListener listener = it.next();
            listener.elementChangeProperty(event);
        }
    }

    public boolean fireVerifyElementCreate(IDesignerElement element) {
        if (!isEventEnabled()) {
            return true;
        }
        DesignerElementEvent event = new DesignerElementEvent(this);
        event.element = element;
        Iterator<IDesignerElementListener> it = this.designerElementListeners.iterator();
        while (it.hasNext()) {
            IDesignerElementListener listener = it.next();
            if (!listener.verifyCreate(event)) {
                return false;
            }
        }
        return true;
    }

    public boolean fireVerifyElementDelete(IDesignerElement element) {
        if (!isEventEnabled()) {
            return true;
        }
        DesignerElementEvent event = new DesignerElementEvent(this);
        event.element = element;
        Iterator<IDesignerElementListener> it = this.designerElementListeners.iterator();
        while (it.hasNext()) {
            IDesignerElementListener listener = it.next();
            if (!listener.verifyDelete(event)) {
                return false;
            }
        }
        return true;
    }

    public boolean fireVerifyElementChangeProperty(IDesignerElement element, String propertyName) {
        if (!isEventEnabled()) {
            return true;
        }
        DesignerElementEvent event = new DesignerElementEvent(this);
        event.element = element;
        event.propertyName = propertyName;
        Iterator<IDesignerElementListener> it = this.designerElementListeners.iterator();
        while (it.hasNext()) {
            IDesignerElementListener listener = it.next();
            if (!listener.verifyChangeProperty(event)) {
                return false;
            }
        }
        return true;
    }

    public void fireFigureMove(IFigureElement element) {
        if (!isEventEnabled()) {
            return;
        }
        FigureEvent event = new FigureEvent(this);
        event.element = element;
        Iterator<IFigureListener> it = this.figureListeners.iterator();
        while (it.hasNext()) {
            IFigureListener listener = it.next();
            listener.figureMove(event);
        }
    }

    public void fireFigureResize(IFigureElement element) {
        if (!isEventEnabled()) {
            return;
        }
        FigureEvent event = new FigureEvent(this);
        event.element = element;
        Iterator<IFigureListener> it = this.figureListeners.iterator();
        while (it.hasNext()) {
            IFigureListener listener = it.next();
            listener.figureResize(event);
        }
    }

    public void fireFigureLayoutDataChange(IFigureElement element, String propertyName) {
        if (!isEventEnabled()) {
            return;
        }
        FigureEvent event = new FigureEvent(this);
        event.element = element;
        event.propertyName = propertyName;
        Iterator<IFigureListener> it = this.figureListeners.iterator();
        while (it.hasNext()) {
            IFigureListener listener = it.next();
            listener.figureLayoutDataChange(event);
        }
    }

    public boolean fireVerifyFigureMove(IFigureElement element) {
        if (!isEventEnabled()) {
            return true;
        }
        FigureEvent event = new FigureEvent(this);
        event.element = element;
        Iterator<IFigureListener> it = this.figureListeners.iterator();
        while (it.hasNext()) {
            IFigureListener listener = it.next();
            if (!listener.verifyMove(event)) {
                return false;
            }
        }
        return true;
    }

    public boolean fireVerifyFigureResize(IFigureElement element) {
        if (!isEventEnabled()) {
            return true;
        }
        FigureEvent event = new FigureEvent(this);
        event.element = element;
        Iterator<IFigureListener> it = this.figureListeners.iterator();
        while (it.hasNext()) {
            IFigureListener listener = it.next();
            if (!listener.verifyResize(event)) {
                return false;
            }
        }
        return true;
    }

    public void fireCompositeAddChild(ICompositeElement composite, IDesignerElement child) {
        if (!isEventEnabled()) {
            return;
        }
        CompositeEvent event = new CompositeEvent(this);
        event.composite = composite;
        event.child = child;
        Iterator<ICompositeListener> it = this.compositeListeners.iterator();
        while (it.hasNext()) {
            ICompositeListener listener = it.next();
            listener.childAdd(event);
        }
    }

    public void fireCompositeRemoveChild(ICompositeElement composite, IDesignerElement child) {
        if (!isEventEnabled()) {
            return;
        }
        CompositeEvent event = new CompositeEvent(this);
        event.composite = composite;
        event.child = child;
        Iterator<ICompositeListener> it = this.compositeListeners.iterator();
        while (it.hasNext()) {
            ICompositeListener listener = it.next();
            listener.childRemove(event);
        }
    }

    public void fireCompositeChangeLayout(ICompositeElement composite) {
        if (!isEventEnabled()) {
            return;
        }
        CompositeEvent event = new CompositeEvent(this);
        event.composite = composite;
        Iterator<ICompositeListener> it = this.compositeListeners.iterator();
        while (it.hasNext()) {
            ICompositeListener listener = it.next();
            listener.layoutChange(event);
        }
    }

    public void fireCompositeChangeLayoutProperty(ICompositeElement composite, String propertyName) {
        if (!isEventEnabled()) {
            return;
        }
        CompositeEvent event = new CompositeEvent(this);
        event.composite = composite;
        event.propertyName = propertyName;
        Iterator<ICompositeListener> it = this.compositeListeners.iterator();
        while (it.hasNext()) {
            ICompositeListener listener = it.next();
            listener.layoutChange(event);
        }
    }

    public boolean fireVerifyCompositeAddChild(ICompositeElement composite, IDesignerElement child) {
        if (!isEventEnabled()) {
            return true;
        }
        CompositeEvent event = new CompositeEvent(this);
        event.composite = composite;
        event.child = child;
        Iterator<ICompositeListener> it = this.compositeListeners.iterator();
        while (it.hasNext()) {
            ICompositeListener listener = it.next();
            if (!listener.verifyAddChild(event)) {
                return false;
            }
        }
        return true;
    }

    public boolean fireVerifyCompositeRemoveChild(ICompositeElement composite, IDesignerElement child) {
        if (!isEventEnabled()) {
            return true;
        }
        CompositeEvent event = new CompositeEvent(this);
        event.composite = composite;
        event.child = child;
        Iterator<ICompositeListener> it = this.compositeListeners.iterator();
        while (it.hasNext()) {
            ICompositeListener listener = it.next();
            if (!listener.verifyRemoveChild(event)) {
                return false;
            }
        }
        return true;
    }

    public void fireElementSelected(IDesignerElement[] elements) {
        if (!isEventEnabled()) {
            return;
        }
        SelectionEvent event = new SelectionEvent(this);
        event.elements = elements;
        Iterator<ISelectionListener> it = this.selectionListeners.iterator();
        while (it.hasNext()) {
            ISelectionListener listener = it.next();
            listener.elementSelected(event);
        }
    }
}
